@@ -54,7 +54,7 @@ typedef struct Dav1dTileContext Dav1dTileContext;
 #include "src/msac.h"
 #include "src/picture.h"
 #include "src/recon.h"
-#include "src/ref_mvs.h"
+#include "src/refmvs.h"
 #include "src/thread.h"
 
 typedef struct Dav1dDSPContext {
@@ -146,7 +146,7 @@ struct Dav1dFrameContext {
     Dav1dPicture cur; // during block coding / reconstruction
     Dav1dThreadPicture sr_cur; // after super-resolution upscaling
     Dav1dRef *mvs_ref;
-    refmvs *mvs, *ref_mvs[7];
+    refmvs_temporal_block *mvs, *ref_mvs[7];
     Dav1dRef *ref_mvs_ref[7];
     Dav1dRef *cur_segmap_ref, *prev_segmap_ref;
     uint8_t *cur_segmap;
@@ -187,7 +187,7 @@ struct Dav1dFrameContext {
     const uint8_t *qm[2 /* is_1d */][N_RECT_TX_SIZES][3 /* plane */];
     BlockContext *a;
     int a_sz /* w*tile_rows */;
-    AV1_COMMON *libaom_cm; // FIXME
+    refmvs_frame rf;
     uint8_t jnt_weights[7][7];
     int bitdepth_max;
 
@@ -290,6 +290,7 @@ struct Dav1dTileContext {
     uint16_t al_pal[2 /* a/l */][32 /* bx/y4 */][3 /* plane */][8 /* palette_idx */];
     uint8_t pal_sz_uv[2 /* a/l */][32 /* bx4/by4 */];
     uint8_t txtp_map[32 * 32]; // inter-only
+    refmvs_tile rt;
     ALIGN(union, 64) {
         struct {
             union {
