@@ -885,21 +885,21 @@ static void emu_edge_c(const intptr_t bw, const intptr_t bh,
 
 static void resize_c(pixel *dst, const ptrdiff_t dst_stride,
                      const pixel *src, const ptrdiff_t src_stride,
-                     const int dst_w, const int src_w, int h,
+                     const int dst_w, int h, const int src_w,
                      const int dx, const int mx0 HIGHBD_DECL_SUFFIX)
 {
     do {
         int mx = mx0, src_x = -1;
         for (int x = 0; x < dst_w; x++) {
-            const int16_t *const F = dav1d_resize_filter[mx >> 8];
-            dst[x] = iclip_pixel((F[0] * src[iclip(src_x - 3, 0, src_w - 1)] +
-                                  F[1] * src[iclip(src_x - 2, 0, src_w - 1)] +
-                                  F[2] * src[iclip(src_x - 1, 0, src_w - 1)] +
-                                  F[3] * src[iclip(src_x + 0, 0, src_w - 1)] +
-                                  F[4] * src[iclip(src_x + 1, 0, src_w - 1)] +
-                                  F[5] * src[iclip(src_x + 2, 0, src_w - 1)] +
-                                  F[6] * src[iclip(src_x + 3, 0, src_w - 1)] +
-                                  F[7] * src[iclip(src_x + 4, 0, src_w - 1)] +
+            const int8_t *const F = dav1d_resize_filter[mx >> 8];
+            dst[x] = iclip_pixel((-(F[0] * src[iclip(src_x - 3, 0, src_w - 1)] +
+                                    F[1] * src[iclip(src_x - 2, 0, src_w - 1)] +
+                                    F[2] * src[iclip(src_x - 1, 0, src_w - 1)] +
+                                    F[3] * src[iclip(src_x + 0, 0, src_w - 1)] +
+                                    F[4] * src[iclip(src_x + 1, 0, src_w - 1)] +
+                                    F[5] * src[iclip(src_x + 2, 0, src_w - 1)] +
+                                    F[6] * src[iclip(src_x + 3, 0, src_w - 1)] +
+                                    F[7] * src[iclip(src_x + 4, 0, src_w - 1)]) +
                                   64) >> 7);
             mx += dx;
             src_x += mx >> 14;
