@@ -37,25 +37,21 @@ static void default_free_callback(const uint8_t *const data, void *const user_da
 }
 
 Dav1dRef *dav1d_ref_create(const size_t size) {
-    Dav1dRef *res;
     void *data = dav1d_alloc_aligned(size, 32);
-    if (!data) {
-        return NULL;
-    }
+    if (!data) return NULL;
 
-    res = dav1d_ref_wrap(data, default_free_callback, data);
-    if (!res) {
-        dav1d_free_aligned(data);
-    } else {
+    Dav1dRef *const res = dav1d_ref_wrap(data, default_free_callback, data);
+    if (res)
         res->data = data;
-    }
+    else
+        dav1d_free_aligned(data);
 
     return res;
 }
 
 Dav1dRef *dav1d_ref_wrap(const uint8_t *const ptr,
                          void (*free_callback)(const uint8_t *data, void *user_data),
-                         void *user_data)
+                         void *const user_data)
 {
     Dav1dRef *res = malloc(sizeof(Dav1dRef));
     if (!res) return NULL;
